library github_hook.test_util;

/// Corresponds to X-GitHub-Event: issues
const issueUnlabeledBody = r'''{
  "action": "unlabeled",
  "issue": {
    "url": "https://api.github.com/repos/dart-lang/coverage/issues/51",
    "labels_url": "https://api.github.com/repos/dart-lang/coverage/issues/51/labels{/name}",
    "comments_url": "https://api.github.com/repos/dart-lang/coverage/issues/51/comments",
    "events_url": "https://api.github.com/repos/dart-lang/coverage/issues/51/events",
    "html_url": "https://github.com/dart-lang/coverage/issues/51",
    "id": 58590379,
    "number": 51,
    "title": "Example repo and coverage.json",
    "user": {
      "login": "stevepeak",
      "id": 2041757,
      "avatar_url": "https://avatars.githubusercontent.com/u/2041757?v=3",
      "gravatar_id": "",
      "url": "https://api.github.com/users/stevepeak",
      "html_url": "https://github.com/stevepeak",
      "followers_url": "https://api.github.com/users/stevepeak/followers",
      "following_url": "https://api.github.com/users/stevepeak/following{/other_user}",
      "gists_url": "https://api.github.com/users/stevepeak/gists{/gist_id}",
      "starred_url": "https://api.github.com/users/stevepeak/starred{/owner}{/repo}",
      "subscriptions_url": "https://api.github.com/users/stevepeak/subscriptions",
      "organizations_url": "https://api.github.com/users/stevepeak/orgs",
      "repos_url": "https://api.github.com/users/stevepeak/repos",
      "events_url": "https://api.github.com/users/stevepeak/events{/privacy}",
      "received_events_url": "https://api.github.com/users/stevepeak/received_events",
      "type": "User",
      "site_admin": false
    },
    "labels": [
      {
        "url": "https://api.github.com/repos/dart-lang/coverage/labels/enhancement",
        "name": "enhancement",
        "color": "84b6eb"
      }
    ],
    "state": "open",
    "locked": false,
    "assignee": null,
    "milestone": null,
    "comments": 3,
    "created_at": "2015-02-23T14:14:21Z",
    "updated_at": "2015-06-18T00:51:26Z",
    "closed_at": null,
    "body": "> I'm looking to add support for Dart to [codecov.io](https://codecov.io) (full disclosure: I'm the founder)\r\n\r\nI'm not familiar with Dart and hoping someone can help show me an example `coverage.json` output file so that I can upload it to Codecov. If you have a very lean example repo I can show customers that would be great!\r\n\r\nThanks ~ Steve"
  },
  "label": {
    "url": "https://api.github.com/repos/dart-lang/coverage/labels/question",
    "name": "question",
    "color": "cc317c"
  },
  "repository": {
    "id": 17006796,
    "name": "coverage",
    "full_name": "dart-lang/coverage",
    "owner": {
      "login": "dart-lang",
      "id": 1609975,
      "avatar_url": "https://avatars.githubusercontent.com/u/1609975?v=3",
      "gravatar_id": "",
      "url": "https://api.github.com/users/dart-lang",
      "html_url": "https://github.com/dart-lang",
      "followers_url": "https://api.github.com/users/dart-lang/followers",
      "following_url": "https://api.github.com/users/dart-lang/following{/other_user}",
      "gists_url": "https://api.github.com/users/dart-lang/gists{/gist_id}",
      "starred_url": "https://api.github.com/users/dart-lang/starred{/owner}{/repo}",
      "subscriptions_url": "https://api.github.com/users/dart-lang/subscriptions",
      "organizations_url": "https://api.github.com/users/dart-lang/orgs",
      "repos_url": "https://api.github.com/users/dart-lang/repos",
      "events_url": "https://api.github.com/users/dart-lang/events{/privacy}",
      "received_events_url": "https://api.github.com/users/dart-lang/received_events",
      "type": "Organization",
      "site_admin": false
    },
    "private": false,
    "html_url": "https://github.com/dart-lang/coverage",
    "description": "Dart coverage data manipulation and formatting",
    "fork": false,
    "url": "https://api.github.com/repos/dart-lang/coverage",
    "forks_url": "https://api.github.com/repos/dart-lang/coverage/forks",
    "keys_url": "https://api.github.com/repos/dart-lang/coverage/keys{/key_id}",
    "collaborators_url": "https://api.github.com/repos/dart-lang/coverage/collaborators{/collaborator}",
    "teams_url": "https://api.github.com/repos/dart-lang/coverage/teams",
    "hooks_url": "https://api.github.com/repos/dart-lang/coverage/hooks",
    "issue_events_url": "https://api.github.com/repos/dart-lang/coverage/issues/events{/number}",
    "events_url": "https://api.github.com/repos/dart-lang/coverage/events",
    "assignees_url": "https://api.github.com/repos/dart-lang/coverage/assignees{/user}",
    "branches_url": "https://api.github.com/repos/dart-lang/coverage/branches{/branch}",
    "tags_url": "https://api.github.com/repos/dart-lang/coverage/tags",
    "blobs_url": "https://api.github.com/repos/dart-lang/coverage/git/blobs{/sha}",
    "git_tags_url": "https://api.github.com/repos/dart-lang/coverage/git/tags{/sha}",
    "git_refs_url": "https://api.github.com/repos/dart-lang/coverage/git/refs{/sha}",
    "trees_url": "https://api.github.com/repos/dart-lang/coverage/git/trees{/sha}",
    "statuses_url": "https://api.github.com/repos/dart-lang/coverage/statuses/{sha}",
    "languages_url": "https://api.github.com/repos/dart-lang/coverage/languages",
    "stargazers_url": "https://api.github.com/repos/dart-lang/coverage/stargazers",
    "contributors_url": "https://api.github.com/repos/dart-lang/coverage/contributors",
    "subscribers_url": "https://api.github.com/repos/dart-lang/coverage/subscribers",
    "subscription_url": "https://api.github.com/repos/dart-lang/coverage/subscription",
    "commits_url": "https://api.github.com/repos/dart-lang/coverage/commits{/sha}",
    "git_commits_url": "https://api.github.com/repos/dart-lang/coverage/git/commits{/sha}",
    "comments_url": "https://api.github.com/repos/dart-lang/coverage/comments{/number}",
    "issue_comment_url": "https://api.github.com/repos/dart-lang/coverage/issues/comments{/number}",
    "contents_url": "https://api.github.com/repos/dart-lang/coverage/contents/{+path}",
    "compare_url": "https://api.github.com/repos/dart-lang/coverage/compare/{base}...{head}",
    "merges_url": "https://api.github.com/repos/dart-lang/coverage/merges",
    "archive_url": "https://api.github.com/repos/dart-lang/coverage/{archive_format}{/ref}",
    "downloads_url": "https://api.github.com/repos/dart-lang/coverage/downloads",
    "issues_url": "https://api.github.com/repos/dart-lang/coverage/issues{/number}",
    "pulls_url": "https://api.github.com/repos/dart-lang/coverage/pulls{/number}",
    "milestones_url": "https://api.github.com/repos/dart-lang/coverage/milestones{/number}",
    "notifications_url": "https://api.github.com/repos/dart-lang/coverage/notifications{?since,all,participating}",
    "labels_url": "https://api.github.com/repos/dart-lang/coverage/labels{/name}",
    "releases_url": "https://api.github.com/repos/dart-lang/coverage/releases{/id}",
    "created_at": "2014-02-20T02:25:03Z",
    "updated_at": "2015-05-20T23:00:39Z",
    "pushed_at": "2015-06-18T00:32:59Z",
    "git_url": "git://github.com/dart-lang/coverage.git",
    "ssh_url": "git@github.com:dart-lang/coverage.git",
    "clone_url": "https://github.com/dart-lang/coverage.git",
    "svn_url": "https://github.com/dart-lang/coverage",
    "homepage": "https://pub.dartlang.org/packages/coverage",
    "size": 1040,
    "stargazers_count": 17,
    "watchers_count": 17,
    "language": "Dart",
    "has_issues": true,
    "has_downloads": true,
    "has_wiki": true,
    "has_pages": false,
    "forks_count": 9,
    "mirror_url": null,
    "open_issues_count": 13,
    "forks": 9,
    "open_issues": 13,
    "watchers": 17,
    "default_branch": "master"
  },
  "organization": {
    "login": "dart-lang",
    "id": 1609975,
    "url": "https://api.github.com/orgs/dart-lang",
    "repos_url": "https://api.github.com/orgs/dart-lang/repos",
    "events_url": "https://api.github.com/orgs/dart-lang/events",
    "members_url": "https://api.github.com/orgs/dart-lang/members{/member}",
    "public_members_url": "https://api.github.com/orgs/dart-lang/public_members{/member}",
    "avatar_url": "https://avatars.githubusercontent.com/u/1609975?v=3",
    "description": "Dart is an open-source, scalable programming language, with robust libraries and runtimes, for building web, server, and mobile apps."
  },
  "sender": {
    "login": "kevmoo",
    "id": 17034,
    "avatar_url": "https://avatars.githubusercontent.com/u/17034?v=3",
    "gravatar_id": "",
    "url": "https://api.github.com/users/kevmoo",
    "html_url": "https://github.com/kevmoo",
    "followers_url": "https://api.github.com/users/kevmoo/followers",
    "following_url": "https://api.github.com/users/kevmoo/following{/other_user}",
    "gists_url": "https://api.github.com/users/kevmoo/gists{/gist_id}",
    "starred_url": "https://api.github.com/users/kevmoo/starred{/owner}{/repo}",
    "subscriptions_url": "https://api.github.com/users/kevmoo/subscriptions",
    "organizations_url": "https://api.github.com/users/kevmoo/orgs",
    "repos_url": "https://api.github.com/users/kevmoo/repos",
    "events_url": "https://api.github.com/users/kevmoo/events{/privacy}",
    "received_events_url": "https://api.github.com/users/kevmoo/received_events",
    "type": "User",
    "site_admin": false
  }
}''';

/// Corresponds to X-GitHub-Event: issues
const issueLabeledBody = r'''{
  "action": "labeled",
  "issue": {
    "url": "https://api.github.com/repos/dart-lang/coverage/issues/51",
    "labels_url": "https://api.github.com/repos/dart-lang/coverage/issues/51/labels{/name}",
    "comments_url": "https://api.github.com/repos/dart-lang/coverage/issues/51/comments",
    "events_url": "https://api.github.com/repos/dart-lang/coverage/issues/51/events",
    "html_url": "https://github.com/dart-lang/coverage/issues/51",
    "id": 58590379,
    "number": 51,
    "title": "Example repo and coverage.json",
    "user": {
      "login": "stevepeak",
      "id": 2041757,
      "avatar_url": "https://avatars.githubusercontent.com/u/2041757?v=3",
      "gravatar_id": "",
      "url": "https://api.github.com/users/stevepeak",
      "html_url": "https://github.com/stevepeak",
      "followers_url": "https://api.github.com/users/stevepeak/followers",
      "following_url": "https://api.github.com/users/stevepeak/following{/other_user}",
      "gists_url": "https://api.github.com/users/stevepeak/gists{/gist_id}",
      "starred_url": "https://api.github.com/users/stevepeak/starred{/owner}{/repo}",
      "subscriptions_url": "https://api.github.com/users/stevepeak/subscriptions",
      "organizations_url": "https://api.github.com/users/stevepeak/orgs",
      "repos_url": "https://api.github.com/users/stevepeak/repos",
      "events_url": "https://api.github.com/users/stevepeak/events{/privacy}",
      "received_events_url": "https://api.github.com/users/stevepeak/received_events",
      "type": "User",
      "site_admin": false
    },
    "labels": [
      {
        "url": "https://api.github.com/repos/dart-lang/coverage/labels/question",
        "name": "question",
        "color": "cc317c"
      }
    ],
    "state": "open",
    "locked": false,
    "assignee": null,
    "milestone": null,
    "comments": 3,
    "created_at": "2015-02-23T14:14:21Z",
    "updated_at": "2015-06-18T00:48:03Z",
    "closed_at": null,
    "body": "> I'm looking to add support for Dart to [codecov.io](https://codecov.io) (full disclosure: I'm the founder)\r\n\r\nI'm not familiar with Dart and hoping someone can help show me an example `coverage.json` output file so that I can upload it to Codecov. If you have a very lean example repo I can show customers that would be great!\r\n\r\nThanks ~ Steve"
  },
  "label": {
    "url": "https://api.github.com/repos/dart-lang/coverage/labels/question",
    "name": "question",
    "color": "cc317c"
  },
  "repository": {
    "id": 17006796,
    "name": "coverage",
    "full_name": "dart-lang/coverage",
    "owner": {
      "login": "dart-lang",
      "id": 1609975,
      "avatar_url": "https://avatars.githubusercontent.com/u/1609975?v=3",
      "gravatar_id": "",
      "url": "https://api.github.com/users/dart-lang",
      "html_url": "https://github.com/dart-lang",
      "followers_url": "https://api.github.com/users/dart-lang/followers",
      "following_url": "https://api.github.com/users/dart-lang/following{/other_user}",
      "gists_url": "https://api.github.com/users/dart-lang/gists{/gist_id}",
      "starred_url": "https://api.github.com/users/dart-lang/starred{/owner}{/repo}",
      "subscriptions_url": "https://api.github.com/users/dart-lang/subscriptions",
      "organizations_url": "https://api.github.com/users/dart-lang/orgs",
      "repos_url": "https://api.github.com/users/dart-lang/repos",
      "events_url": "https://api.github.com/users/dart-lang/events{/privacy}",
      "received_events_url": "https://api.github.com/users/dart-lang/received_events",
      "type": "Organization",
      "site_admin": false
    },
    "private": false,
    "html_url": "https://github.com/dart-lang/coverage",
    "description": "Dart coverage data manipulation and formatting",
    "fork": false,
    "url": "https://api.github.com/repos/dart-lang/coverage",
    "forks_url": "https://api.github.com/repos/dart-lang/coverage/forks",
    "keys_url": "https://api.github.com/repos/dart-lang/coverage/keys{/key_id}",
    "collaborators_url": "https://api.github.com/repos/dart-lang/coverage/collaborators{/collaborator}",
    "teams_url": "https://api.github.com/repos/dart-lang/coverage/teams",
    "hooks_url": "https://api.github.com/repos/dart-lang/coverage/hooks",
    "issue_events_url": "https://api.github.com/repos/dart-lang/coverage/issues/events{/number}",
    "events_url": "https://api.github.com/repos/dart-lang/coverage/events",
    "assignees_url": "https://api.github.com/repos/dart-lang/coverage/assignees{/user}",
    "branches_url": "https://api.github.com/repos/dart-lang/coverage/branches{/branch}",
    "tags_url": "https://api.github.com/repos/dart-lang/coverage/tags",
    "blobs_url": "https://api.github.com/repos/dart-lang/coverage/git/blobs{/sha}",
    "git_tags_url": "https://api.github.com/repos/dart-lang/coverage/git/tags{/sha}",
    "git_refs_url": "https://api.github.com/repos/dart-lang/coverage/git/refs{/sha}",
    "trees_url": "https://api.github.com/repos/dart-lang/coverage/git/trees{/sha}",
    "statuses_url": "https://api.github.com/repos/dart-lang/coverage/statuses/{sha}",
    "languages_url": "https://api.github.com/repos/dart-lang/coverage/languages",
    "stargazers_url": "https://api.github.com/repos/dart-lang/coverage/stargazers",
    "contributors_url": "https://api.github.com/repos/dart-lang/coverage/contributors",
    "subscribers_url": "https://api.github.com/repos/dart-lang/coverage/subscribers",
    "subscription_url": "https://api.github.com/repos/dart-lang/coverage/subscription",
    "commits_url": "https://api.github.com/repos/dart-lang/coverage/commits{/sha}",
    "git_commits_url": "https://api.github.com/repos/dart-lang/coverage/git/commits{/sha}",
    "comments_url": "https://api.github.com/repos/dart-lang/coverage/comments{/number}",
    "issue_comment_url": "https://api.github.com/repos/dart-lang/coverage/issues/comments{/number}",
    "contents_url": "https://api.github.com/repos/dart-lang/coverage/contents/{+path}",
    "compare_url": "https://api.github.com/repos/dart-lang/coverage/compare/{base}...{head}",
    "merges_url": "https://api.github.com/repos/dart-lang/coverage/merges",
    "archive_url": "https://api.github.com/repos/dart-lang/coverage/{archive_format}{/ref}",
    "downloads_url": "https://api.github.com/repos/dart-lang/coverage/downloads",
    "issues_url": "https://api.github.com/repos/dart-lang/coverage/issues{/number}",
    "pulls_url": "https://api.github.com/repos/dart-lang/coverage/pulls{/number}",
    "milestones_url": "https://api.github.com/repos/dart-lang/coverage/milestones{/number}",
    "notifications_url": "https://api.github.com/repos/dart-lang/coverage/notifications{?since,all,participating}",
    "labels_url": "https://api.github.com/repos/dart-lang/coverage/labels{/name}",
    "releases_url": "https://api.github.com/repos/dart-lang/coverage/releases{/id}",
    "created_at": "2014-02-20T02:25:03Z",
    "updated_at": "2015-05-20T23:00:39Z",
    "pushed_at": "2015-06-18T00:32:59Z",
    "git_url": "git://github.com/dart-lang/coverage.git",
    "ssh_url": "git@github.com:dart-lang/coverage.git",
    "clone_url": "https://github.com/dart-lang/coverage.git",
    "svn_url": "https://github.com/dart-lang/coverage",
    "homepage": "https://pub.dartlang.org/packages/coverage",
    "size": 1040,
    "stargazers_count": 17,
    "watchers_count": 17,
    "language": "Dart",
    "has_issues": true,
    "has_downloads": true,
    "has_wiki": true,
    "has_pages": false,
    "forks_count": 9,
    "mirror_url": null,
    "open_issues_count": 13,
    "forks": 9,
    "open_issues": 13,
    "watchers": 17,
    "default_branch": "master"
  },
  "organization": {
    "login": "dart-lang",
    "id": 1609975,
    "url": "https://api.github.com/orgs/dart-lang",
    "repos_url": "https://api.github.com/orgs/dart-lang/repos",
    "events_url": "https://api.github.com/orgs/dart-lang/events",
    "members_url": "https://api.github.com/orgs/dart-lang/members{/member}",
    "public_members_url": "https://api.github.com/orgs/dart-lang/public_members{/member}",
    "avatar_url": "https://avatars.githubusercontent.com/u/1609975?v=3",
    "description": "Dart is an open-source, scalable programming language, with robust libraries and runtimes, for building web, server, and mobile apps."
  },
  "sender": {
    "login": "kevmoo",
    "id": 17034,
    "avatar_url": "https://avatars.githubusercontent.com/u/17034?v=3",
    "gravatar_id": "",
    "url": "https://api.github.com/users/kevmoo",
    "html_url": "https://github.com/kevmoo",
    "followers_url": "https://api.github.com/users/kevmoo/followers",
    "following_url": "https://api.github.com/users/kevmoo/following{/other_user}",
    "gists_url": "https://api.github.com/users/kevmoo/gists{/gist_id}",
    "starred_url": "https://api.github.com/users/kevmoo/starred{/owner}{/repo}",
    "subscriptions_url": "https://api.github.com/users/kevmoo/subscriptions",
    "organizations_url": "https://api.github.com/users/kevmoo/orgs",
    "repos_url": "https://api.github.com/users/kevmoo/repos",
    "events_url": "https://api.github.com/users/kevmoo/events{/privacy}",
    "received_events_url": "https://api.github.com/users/kevmoo/received_events",
    "type": "User",
    "site_admin": false
  }
}''';

/// Corresponds to X-GitHub-Event: issues
const issueOpenedBody = r'''{
  "action":"opened",
  "issue":{
    "url":"https://api.github.com/repos/dart-lang/sdk/issues/23664",
    "labels_url":"https://api.github.com/repos/dart-lang/sdk/issues/23664/labels{/name}",
    "comments_url":"https://api.github.com/repos/dart-lang/sdk/issues/23664/comments",
    "events_url":"https://api.github.com/repos/dart-lang/sdk/issues/23664/events",
    "html_url":"https://github.com/dart-lang/sdk/issues/23664",
    "id":89123320,
    "number":23664,
    "title":"dart2js: bug in world invariant?",
    "user":{
      "login":"sigmundch",
      "id":2049220,
      "avatar_url":"https://avatars.githubusercontent.com/u/2049220?v=3",
      "gravatar_id":"",
      "url":"https://api.github.com/users/sigmundch",
      "html_url":"https://github.com/sigmundch",
      "followers_url":"https://api.github.com/users/sigmundch/followers",
      "following_url":"https://api.github.com/users/sigmundch/following{/other_user}",
      "gists_url":"https://api.github.com/users/sigmundch/gists{/gist_id}",
      "starred_url":"https://api.github.com/users/sigmundch/starred{/owner}{/repo}",
      "subscriptions_url":"https://api.github.com/users/sigmundch/subscriptions",
      "organizations_url":"https://api.github.com/users/sigmundch/orgs",
      "repos_url":"https://api.github.com/users/sigmundch/repos",
      "events_url":"https://api.github.com/users/sigmundch/events{/privacy}",
      "received_events_url":"https://api.github.com/users/sigmundch/received_events",
      "type":"User",
      "site_admin":false
    },
    "labels":[
      {
        "url":"https://api.github.com/repos/dart-lang/sdk/labels/Area-Dart2JS",
        "name":"Area-Dart2JS",
        "color":"ededed"
      },
      {
        "url":"https://api.github.com/repos/dart-lang/sdk/labels/Priority-Medium",
        "name":"Priority-Medium",
        "color":"ededed"
      },
      {
        "url":"https://api.github.com/repos/dart-lang/sdk/labels/Triaged",
        "name":"Triaged",
        "color":"ededed"
      },
      {
        "url":"https://api.github.com/repos/dart-lang/sdk/labels/Type-Defect",
        "name":"Type-Defect",
        "color":"ededed"
      }
    ],
    "state":"open",
    "locked":false,
    "assignee":null,
    "milestone":null,
    "comments":0,
    "created_at":"2015-06-17T20:52:25Z",
    "updated_at":"2015-06-17T20:52:25Z",
    "closed_at":null,
    "body":"The [dart docs](https://github.com/dart-lang/sdk/blob/master/pkg/compiler/lib/src/world.dart#L49) for `world.subtypeOf` and `world.subclassOf` indicate that the result would include the given class as aprt of the results if it is live.\r\n\r\nIn a simple program like:\r\n```dart\r\nclass A {}\r\nmain() => new A();\r\n```\r\n\r\nIf I query the world for subtypes-of A (or subclasses of A) I get an empty set. \r\n\r\nSeems like a bug in `populate`, but I wanted to first confirm. @johnniwinther - do you agree?"
  },
  "repository":{
    "id":35726310,
    "name":"sdk",
    "full_name":"dart-lang/sdk",
    "owner":{
      "login":"dart-lang",
      "id":1609975,
      "avatar_url":"https://avatars.githubusercontent.com/u/1609975?v=3",
      "gravatar_id":"",
      "url":"https://api.github.com/users/dart-lang",
      "html_url":"https://github.com/dart-lang",
      "followers_url":"https://api.github.com/users/dart-lang/followers",
      "following_url":"https://api.github.com/users/dart-lang/following{/other_user}",
      "gists_url":"https://api.github.com/users/dart-lang/gists{/gist_id}",
      "starred_url":"https://api.github.com/users/dart-lang/starred{/owner}{/repo}",
      "subscriptions_url":"https://api.github.com/users/dart-lang/subscriptions",
      "organizations_url":"https://api.github.com/users/dart-lang/orgs",
      "repos_url":"https://api.github.com/users/dart-lang/repos",
      "events_url":"https://api.github.com/users/dart-lang/events{/privacy}",
      "received_events_url":"https://api.github.com/users/dart-lang/received_events",
      "type":"Organization",
      "site_admin":false
    },
    "private":false,
    "html_url":"https://github.com/dart-lang/sdk",
    "description":"The Dart SDK, including the VM, dart2js, core libraries, and more.",
    "fork":false,
    "url":"https://api.github.com/repos/dart-lang/sdk",
    "forks_url":"https://api.github.com/repos/dart-lang/sdk/forks",
    "keys_url":"https://api.github.com/repos/dart-lang/sdk/keys{/key_id}",
    "collaborators_url":"https://api.github.com/repos/dart-lang/sdk/collaborators{/collaborator}",
    "teams_url":"https://api.github.com/repos/dart-lang/sdk/teams",
    "hooks_url":"https://api.github.com/repos/dart-lang/sdk/hooks",
    "issue_events_url":"https://api.github.com/repos/dart-lang/sdk/issues/events{/number}",
    "events_url":"https://api.github.com/repos/dart-lang/sdk/events",
    "assignees_url":"https://api.github.com/repos/dart-lang/sdk/assignees{/user}",
    "branches_url":"https://api.github.com/repos/dart-lang/sdk/branches{/branch}",
    "tags_url":"https://api.github.com/repos/dart-lang/sdk/tags",
    "blobs_url":"https://api.github.com/repos/dart-lang/sdk/git/blobs{/sha}",
    "git_tags_url":"https://api.github.com/repos/dart-lang/sdk/git/tags{/sha}",
    "git_refs_url":"https://api.github.com/repos/dart-lang/sdk/git/refs{/sha}",
    "trees_url":"https://api.github.com/repos/dart-lang/sdk/git/trees{/sha}",
    "statuses_url":"https://api.github.com/repos/dart-lang/sdk/statuses/{sha}",
    "languages_url":"https://api.github.com/repos/dart-lang/sdk/languages",
    "stargazers_url":"https://api.github.com/repos/dart-lang/sdk/stargazers",
    "contributors_url":"https://api.github.com/repos/dart-lang/sdk/contributors",
    "subscribers_url":"https://api.github.com/repos/dart-lang/sdk/subscribers",
    "subscription_url":"https://api.github.com/repos/dart-lang/sdk/subscription",
    "commits_url":"https://api.github.com/repos/dart-lang/sdk/commits{/sha}",
    "git_commits_url":"https://api.github.com/repos/dart-lang/sdk/git/commits{/sha}",
    "comments_url":"https://api.github.com/repos/dart-lang/sdk/comments{/number}",
    "issue_comment_url":"https://api.github.com/repos/dart-lang/sdk/issues/comments{/number}",
    "contents_url":"https://api.github.com/repos/dart-lang/sdk/contents/{+path}",
    "compare_url":"https://api.github.com/repos/dart-lang/sdk/compare/{base}...{head}",
    "merges_url":"https://api.github.com/repos/dart-lang/sdk/merges",
    "archive_url":"https://api.github.com/repos/dart-lang/sdk/{archive_format}{/ref}",
    "downloads_url":"https://api.github.com/repos/dart-lang/sdk/downloads",
    "issues_url":"https://api.github.com/repos/dart-lang/sdk/issues{/number}",
    "pulls_url":"https://api.github.com/repos/dart-lang/sdk/pulls{/number}",
    "milestones_url":"https://api.github.com/repos/dart-lang/sdk/milestones{/number}",
    "notifications_url":"https://api.github.com/repos/dart-lang/sdk/notifications{?since,all,participating}",
    "labels_url":"https://api.github.com/repos/dart-lang/sdk/labels{/name}",
    "releases_url":"https://api.github.com/repos/dart-lang/sdk/releases{/id}",
    "created_at":"2015-05-16T14:14:58Z",
    "updated_at":"2015-06-17T18:30:46Z",
    "pushed_at":"2015-06-17T20:50:33Z",
    "git_url":"git://github.com/dart-lang/sdk.git",
    "ssh_url":"git@github.com:dart-lang/sdk.git",
    "clone_url":"https://github.com/dart-lang/sdk.git",
    "svn_url":"https://github.com/dart-lang/sdk",
    "homepage":"https://www.dartlang.org/",
    "size":104771,
    "stargazers_count":218,
    "watchers_count":218,
    "language":"Dart",
    "has_issues":true,
    "has_downloads":true,
    "has_wiki":true,
    "has_pages":false,
    "forks_count":18,
    "mirror_url":null,
    "open_issues_count":3280,
    "forks":18,
    "open_issues":3280,
    "watchers":218,
    "default_branch":"master"
  },
  "organization":{
    "login":"dart-lang",
    "id":1609975,
    "url":"https://api.github.com/orgs/dart-lang",
    "repos_url":"https://api.github.com/orgs/dart-lang/repos",
    "events_url":"https://api.github.com/orgs/dart-lang/events",
    "members_url":"https://api.github.com/orgs/dart-lang/members{/member}",
    "public_members_url":"https://api.github.com/orgs/dart-lang/public_members{/member}",
    "avatar_url":"https://avatars.githubusercontent.com/u/1609975?v=3",
    "description":"Dart is an open-source, scalable programming language, with robust libraries and runtimes, for building web, server, and mobile apps."
  },
  "sender":{
    "login":"sigmundch",
    "id":2049220,
    "avatar_url":"https://avatars.githubusercontent.com/u/2049220?v=3",
    "gravatar_id":"",
    "url":"https://api.github.com/users/sigmundch",
    "html_url":"https://github.com/sigmundch",
    "followers_url":"https://api.github.com/users/sigmundch/followers",
    "following_url":"https://api.github.com/users/sigmundch/following{/other_user}",
    "gists_url":"https://api.github.com/users/sigmundch/gists{/gist_id}",
    "starred_url":"https://api.github.com/users/sigmundch/starred{/owner}{/repo}",
    "subscriptions_url":"https://api.github.com/users/sigmundch/subscriptions",
    "organizations_url":"https://api.github.com/users/sigmundch/orgs",
    "repos_url":"https://api.github.com/users/sigmundch/repos",
    "events_url":"https://api.github.com/users/sigmundch/events{/privacy}",
    "received_events_url":"https://api.github.com/users/sigmundch/received_events",
    "type":"User",
    "site_admin":false
  }
}''';
